@@ -32,7 +32,9 @@
 #include <libosso-abook/osso-abook-util.h>
 #endif /* FREMANTLE */
 
-
+//#include <hildon/hildon-helper.h>
+//#include <hildon/hildon-defines.h>
+//#include <hildon-mime.h>
 #include "web.h"
 
 #ifdef FREMANTLE
@@ -2098,8 +2100,11 @@ int handle_EAN8(char *data)
 void openURL(char *open)
 {
     GtkWidget *dialog;
-        
-    printf("Opening URL in browser...\n");
+    gchar *uri = g_strdup(open);
+    
+    
+    
+    printf("Opening URL in browser: %s\n", uri);
 
     
 
@@ -2107,18 +2112,18 @@ void openURL(char *open)
             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
             GTK_MESSAGE_QUESTION,
             GTK_BUTTONS_YES_NO,
-            "Open URL: %s", open);
+            "Open URL: %s", uri);
             
-    g_signal_connect(dialog, "response", G_CALLBACK (openURL_response_cb), (gpointer)open);
+    g_signal_connect(dialog, "response", G_CALLBACK (openURL_response_cb), uri);
         
     gtk_widget_show_all (dialog);
     
 }
 
-
+#ifdef N900
 void openURL_response_cb (GtkDialog *dialog, gint response, gpointer user_data)
 {
-    char *open = (char*)user_data;
+    char *uri = (char*)user_data;
     DBusGConnection *connection;
     GError *error = NULL;
     DBusGProxy *proxy;
@@ -2141,9 +2146,9 @@ void openURL_response_cb (GtkDialog *dialog, gint response, gpointer user_data)
 
             error = NULL;
             
-            printf("About to open %s\n", open);
+            printf("About to open %s\n", uri);
             
-            if (!dbus_g_proxy_call (proxy, "load_url", &error, G_TYPE_STRING, open, G_TYPE_INVALID, G_TYPE_INVALID)){
+            if (!dbus_g_proxy_call (proxy, "load_url", &error, G_TYPE_STRING, uri, G_TYPE_INVALID, G_TYPE_INVALID)){
                 printf("%s\n",error->message); // make this a notification eventually
                 g_error_free (error);
             }
@@ -2152,8 +2157,45 @@ void openURL_response_cb (GtkDialog *dialog, gint response, gpointer user_data)
             break; // dialog was cancelled, so do nothing
     }
     printf("Opened URL... leaving.\n");
+    g_free(uri);
 }
 
+#else
+void openURL_response_cb (GtkDialog *dialog, gint response, gpointer user_data)
+{
+    char *uri = (char*)user_data;
+    osso_context_t* osso_context;
+    osso_rpc_t* osso_retval = { 0 };
+
+    gtk_widget_destroy(dialog);
+    
+    
+    switch (response) {
+        case GTK_RESPONSE_YES:
+            /*Create the osso context for the browser application.*/
+            osso_context = osso_initialize("org.maemo.mbarcode", "0.0.1", FALSE, NULL);
+            /*Call the given function.*/
+            
+            printf("Open URL: %s, length=%d\n", uri, strlen(uri));
+            
+            osso_rpc_run(osso_context, "com.nokia.osso_browser","/com/nokia/osso_browser",
+            "com.nokia.osso_browser","open_new_window", NULL, DBUS_TYPE_STRING, uri, DBUS_TYPE_INVALID);
+
+/*
+            osso_rpc_run(osso_context, "com.nokia.osso_browser","/com/nokia/osso_browser/request",
+            "com.nokia.osso_browser","load_url", NULL, DBUS_TYPE_STRING, uri, DBUS_TYPE_INVALID);
+*/
+            /*Free all memory allocated*/
+            osso_deinitialize(osso_context);
+            break;
+        default:
+            break; // dialog was cancelled, so do nothing
+    }
+    printf("Opened URL... leaving.\n");
+    g_free(uri);
+}
+#endif
+
 
 
 #ifdef N900
